getGGAR: Aspect ratio for a ggplot

Description Usage Arguments

View source: R/PlotUtils.R

Description

This internal function attempts to get the aspect ratio of a ggplot. It takes multiple facets into account but only really works for plots where ggplot::coord_fixed() so that the scales on the x and y axes are compatible.

Usage

1

Arguments

p

a ggplot object


MagicForrest/MagicUtils documentation built on Dec. 17, 2021, 2:16 a.m.