This internal function attempts to get the aspect ratio of a ggplot. It takes multiple facets into account but only really works for plots where ggplot::coord_fixed() so that the scales on the x and y axes are compatible.
1 | getGGAR(p)
|
p |
a ggplot object |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.